/*
 * @Company: hugeInfo
 * @Author: ldh
 * @Date: 2022-06-22 11:14:43
 * @LastEditTime: 2024-08-22 20:14:57
 * @LastEditors: dminyi 1301963064@qq.com
 * @Version: 1.0.0
 * @Description: 我的抽屉组件
 */
import React from 'react';
import PropTypes from 'prop-types';
import { Drawer, Space } from 'antd';
import { CloseOutlined } from '@ant-design/icons';
import './index.less';

const MyDrawer = ({
	children,
	visible,
	onClose,
	width = 508,
	title,
	footer = [],
	style = {},
	bodyStyle = {},
	mainStyle = {},
	zIndex = 1000,
	container = false,
	titleBefore=false
}) => {
	return (
		<Drawer
			title=""
			closable={false}
			placement="right"
			visible={!!visible}
			getContainer={container ? 'body' : () => document.getElementById('layoutMain')}
			width={width}
			onClose={onClose}
			style={Object.assign({ position: 'absolute' }, style)}
			bodyStyle={{ padding: 0 }}
			destroyOnClose={true}
			zIndex={zIndex}
		>
			<div className="myDrawer" style={bodyStyle}>
				<div className="myDrawer-header">
					<div className={!titleBefore ? 'myDrawer-header-title' : ''}>{title}</div>
					<CloseOutlined className="myDrawer-header-close" onClick={onClose} />
				</div>
				<div className="myDrawer-main" style={mainStyle}>
					{children}
				</div>
				{footer.length !== 0 && (
					<div className="myDrawer-footer">
						<Space size="large">{footer.map((x) => x)}</Space>
					</div>
				)}
			</div>
		</Drawer>
	);
};

MyDrawer.propTypes = {
	visible: PropTypes.any,
	onClose: PropTypes.func,
	width: PropTypes.any,
	title: PropTypes.any,
	style: PropTypes.object,
	bodyStyle: PropTypes.object,
	mainStyle: PropTypes.object,
	zIndex: PropTypes.number,
};

export default MyDrawer;
